@@ -11,8 +11,6 @@ enum {
 	MAIN_MENU_SYSTEM_SUB = 1<<3,
 	MAIN_MENU_DISTRIBUTION = 1<<4,
 	MAIN_MENU_DISTRIBUTION_SUB = 1<<5,
-	MAIN_MENU_KDE = 1<<6,
-	MAIN_MENU_KDE_SUB = 1<<7,
 	MAIN_MENU_PANEL_SUB = 1<<13,
 	MAIN_MENU_DESKTOP = 1<<14,
 	MAIN_MENU_DESKTOP_SUB = 1<<15
@@ -23,10 +21,15 @@ void		setup_menuitem		(GtkWidget        *menuitem,
 					 GtkWidget        *pixmap,
 					 const char       *title,
 					 gboolean          invisible_mnemonic);
+void            setup_stock_menu_item   (GtkWidget        *item,
+					 GtkIconSize       icon_size,
+					 const char       *stock_id,
+					 const char       *title,
+					 gboolean          invisible_mnemonic);
+
 
 GtkWidget      *create_menu_at          (GtkWidget     *menu,
 					 const char    *menudir,
-					 gboolean       launcher_add,
 					 const char    *dir_name,
 					 gboolean       fake_submenus,
 					 gboolean       force);
